@@ -23,7 +23,7 @@ import logging
 
 from lomond import WebSocket
 from ibm_watson_machine_learning.utils.autoai.enums import (
-    PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
+    PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes, DataConnectionTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType, \
     AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics, LibraryNotCompatible, \
     CannotConnectToWebsocket
@@ -402,6 +402,19 @@ class WMLEngine(BaseEngine):
                 f"wml pipeline: {self._wml_stored_pipeline_details['metadata']['id']}",
         }
 
+        # note: Delete unnecessary keys for connection_asset in training_data_reference
+        for connection in \
+                self._wml_training_metadata[self._wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES] +\
+                [self._wml_training_metadata[self._wml_client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE]]:
+            if connection.get("type") == DataConnectionTypes.CA:
+                try:
+                    del connection["connection"]["secret_access_key"]
+                    del connection["connection"]["access_key_id"]
+                    del connection["connection"]["endpoint_url"]
+                except KeyError:
+                    pass
+        # --- end note
+
     ##########################################################
     #   WML Pipeline Part / AutoPipelineOptimizer Init Part  #
     ##########################################################
