@@ -364,19 +364,19 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 )
 
             elif isinstance(training_data_reference[0].location, AssetLocation) and not self._workspace.wml_client.ICP:
-                try:
-                    connection_id = training_data_reference[0].location._get_connection_id(self._workspace.wml_client)
+                connection_id = training_data_reference[0].location._get_connection_id(self._workspace.wml_client)
 
-                except InvalidDataAsset:
-                    raise InvalidDataAsset(
-                        reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
+                if connection_id is not None:
+                    training_results_reference = DataConnection(
+                        connection_asset_id=connection_id,
+                        location=S3Location(
+                            bucket=training_data_reference[0].location._get_bucket(self._workspace.wml_client),
+                            path="default_autoai_out")
+                    )
 
-                training_results_reference = DataConnection(
-                    connection_asset_id=connection_id,
-                    location=S3Location(
-                        bucket=training_data_reference[0].location._get_bucket(self._workspace.wml_client),
-                        path="default_autoai_out")
-                )
+                else:   # set container output location when default DAta Asset is as a train ref
+                    training_results_reference = DataConnection(
+                        location=ContainerLocation(path="default_autoai_out"))
 
             elif isinstance(training_data_reference[0].location, ContainerLocation) and not self._workspace.wml_client.ICP:
                 training_results_reference = DataConnection(location=ContainerLocation(path="default_autoai_out"))
@@ -400,11 +400,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 )
         # -- end note
         if isinstance(training_results_reference.location, AssetLocation):
-            try:
-                training_results_reference.location._get_connection_id(self._workspace.wml_client)
-
-            except InvalidDataAsset:
-                raise InvalidDataAsset(reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
+            if training_results_reference.location._get_connection_id(self._workspace.wml_client) is None:
+                raise InvalidDataAsset(
+                    reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
 
         # note: results can be stored only on FS or COS
         if not isinstance(training_results_reference.location, (S3Location, FSLocation, AssetLocation, ContainerLocation)):
