@@ -217,10 +217,16 @@ class BaseDataConnection(ABC):
                     if response.status_code == 200:
                         attachment_details = response.json()
                         if 'connection_id' not in attachment_details:
-                            return False
+                            if 'handle' in attachment_details and 'bucket' in attachment_details['handle']:
+                                connection_details = self._create_conn_details_for_container()
+                                attachment_details['connection_path'] = attachment_details['handle']['key']
 
-                        connection_details = self._wml_client.connections.get_details(
-                            attachment_details['connection_id'])
+                            else:
+                                return False
+
+                        else:
+                            connection_details = self._wml_client.connections.get_details(
+                                attachment_details['connection_id'])
 
                     else:
                         raise WMLClientError("Failed while downloading the attachment " + attachment_id)
@@ -262,83 +268,7 @@ class BaseDataConnection(ABC):
                         raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
 
             elif self.type == 'container':
-                if self._wml_client is not None:
-                    if self._wml_client.default_space_id is not None:
-                        details = self._wml_client.spaces.get_details(self._wml_client.default_space_id)
-
-                    else:
-                        project_url = self._wml_client.service_instance._href_definitions.get_project_href(
-                            self._wml_client.default_project_id)
-                        if self._wml_client.ICP:
-                            response = requests.get(
-                                project_url,
-                                headers=self._wml_client._get_headers(),
-                                verify=False
-                            )
-
-                        else:
-                            response = requests.get(
-                                    project_url,
-                                    headers=self._wml_client._get_headers()
-                                )
-
-                        details = response.json()
-
-                    properties = details['entity']['storage']['properties']
-                    properties.update(details['entity']['storage']['properties']['credentials']['editor'])
-                    properties['url'] = properties['endpoint_url']
-                    properties['access_key'] = properties.get('access_key_id')
-                    properties['secret_key'] = properties.get('secret_access_key')
-
-                    connection_details = {
-                        'entity': {
-                            'datasource_type': 'bluemixcloudobjectstorage',
-                            'properties': properties
-                        }
-                    }
-
-                else:
-                    try:
-                        from project_lib import Project
-                        token = os.environ.get('USER_ACCESS_TOKEN')
-
-                        if token is None:
-                            raise NotImplementedError(
-                                f"""To succesfully read the training data used in AutoAI experiment, you need to provide the project token.
-                            **To insert the project token to your notebook:**
-                                Click the More icon on your notebook toolbar and then click Insert project token.
-                                Run the inserted code cell.
-                            Note:
-                            If you are told in a message that no project token exists, click the link in the message to be redirected to the project's Settings page where you can create a project token.
-                            **To create a project token:**
-                                Click New token in the Access tokens section on the Settings page of your project.
-                                Enter a name, select Editor role for the project, and create a token.
-                                Go back to your notebook, click the More icon on the notebook toolbar and then click Insert project token.
-                                Run the inserted code cell."""
-                            )
-
-                        token = token.split('Bearer ')[-1]
-
-                        _project = Project(project_id=os.environ.get('PROJECT_ID'),
-                                           project_access_token=token)
-
-                        details = _project.get_storage_metadata()
-
-                        properties = details['properties']
-                        properties.update(properties['credentials']['editor'])
-                        properties['url'] = properties['endpoint_url']
-                        properties['access_key'] = properties.get('access_key_id')
-                        properties['secret_key'] = properties.get('secret_access_key')
-
-                        connection_details = {
-                            'entity': {
-                                'datasource_type': 'bluemixcloudobjectstorage',
-                                'properties': properties
-                            }
-                        }
-
-                    except ModuleNotFoundError:
-                        raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+                connection_details = self._create_conn_details_for_container()
 
             elif self.type == 's3' or self.type == 'fs':
                 return False
@@ -470,6 +400,40 @@ class BaseDataConnection(ABC):
 
             asset_details = self._wml_client.data_assets._handle_response(200, u'get assets', asset_response)
 
+            attachment_id = asset_details['attachments'][0]['id']
+            if not self._wml_client.ICP and not self._wml_client.WSD:
+                response = requests.get(
+                    self._wml_client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id),
+                    params=self._wml_client.data_assets._client._params(),
+                    headers=self._wml_client.data_assets._client._get_headers())
+            else:
+                response = requests.get(
+                    self._wml_client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id),
+                    params=self._wml_client.data_assets._client._params(),
+                    headers=self._wml_client.data_assets._client._get_headers(),
+                    verify=False)
+
+            if response.status_code == 200:
+                attachment_details = response.json()
+                if "url" in attachment_details:
+                    file_asset_url = attachment_details['url']
+                    csv_response = requests.get(file_asset_url, verify=False)
+
+                    if csv_response.status_code != 200:
+                        raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+
+                    downloaded_asset = csv_response.content
+
+                    # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+                    buffer = io.BytesIO(downloaded_asset)
+                    data = try_load_dataset(buffer=buffer,
+                                            sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
+                                            separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                            encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                            )
+
+                    return data
+
             # note: read the csv url
             if 'handle' in asset_details['attachments'][0]:
                 attachment_url = asset_details['attachments'][0]['handle']['key']
@@ -500,6 +464,7 @@ class BaseDataConnection(ABC):
                                         )
 
                 return data
+
             else:
                 # NFS scenario
                 connection_id = asset_details['attachments'][0]['connection_id']
@@ -693,3 +658,85 @@ class BaseDataConnection(ABC):
                                 )
 
         return data
+
+
+    def _create_conn_details_for_container(self) -> dict:
+        if self._wml_client is not None:
+            if self._wml_client.default_space_id is not None:
+                details = self._wml_client.spaces.get_details(self._wml_client.default_space_id)
+
+            else:
+                project_url = self._wml_client.service_instance._href_definitions.get_project_href(
+                    self._wml_client.default_project_id)
+                if self._wml_client.ICP:
+                    response = requests.get(
+                        project_url,
+                        headers=self._wml_client._get_headers(),
+                        verify=False
+                    )
+
+                else:
+                    response = requests.get(
+                        project_url,
+                        headers=self._wml_client._get_headers()
+                    )
+
+                details = response.json()
+
+            properties = details['entity']['storage']['properties']
+            properties.update(details['entity']['storage']['properties']['credentials']['editor'])
+            properties['url'] = properties['endpoint_url']
+            properties['access_key'] = properties.get('access_key_id')
+            properties['secret_key'] = properties.get('secret_access_key')
+
+            connection_details = {
+                'entity': {
+                    'datasource_type': 'bluemixcloudobjectstorage',
+                    'properties': properties
+                }
+            }
+
+        else:
+            try:
+                from project_lib import Project
+                token = os.environ.get('USER_ACCESS_TOKEN')
+
+                if token is None:
+                    raise NotImplementedError(
+                        f"""To succesfully read the training data used in AutoAI experiment, you need to provide the project token.
+                    **To insert the project token to your notebook:**
+                        Click the More icon on your notebook toolbar and then click Insert project token.
+                        Run the inserted code cell.
+                    Note:
+                    If you are told in a message that no project token exists, click the link in the message to be redirected to the project's Settings page where you can create a project token.
+                    **To create a project token:**
+                        Click New token in the Access tokens section on the Settings page of your project.
+                        Enter a name, select Editor role for the project, and create a token.
+                        Go back to your notebook, click the More icon on the notebook toolbar and then click Insert project token.
+                        Run the inserted code cell."""
+                    )
+
+                token = token.split('Bearer ')[-1]
+
+                _project = Project(project_id=os.environ.get('PROJECT_ID'),
+                                   project_access_token=token)
+
+                details = _project.get_storage_metadata()
+
+                properties = details['properties']
+                properties.update(properties['credentials']['editor'])
+                properties['url'] = properties['endpoint_url']
+                properties['access_key'] = properties.get('access_key_id')
+                properties['secret_key'] = properties.get('secret_access_key')
+
+                connection_details = {
+                    'entity': {
+                        'datasource_type': 'bluemixcloudobjectstorage',
+                        'properties': properties
+                    }
+                }
+
+            except ModuleNotFoundError:
+                raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+
+        return connection_details
\ No newline at end of file
