@@ -545,15 +545,16 @@ class DataConnection(BaseDataConnection):
                     f"Error: {cos_access_exception}")
 
         elif self.type == DataConnectionTypes.DS:
-
-            if self._obm:
-                raise NotImplementedError("Multiple files for CP4D / WML Server is not yet supported.")
-
             try:
                 with all_logging_disabled():
                     if self._check_if_connection_asset_is_s3():
                         cos_client = self._init_cos_client()
-                        data = self._download_data_from_cos(cos_client=cos_client)
+
+                        if self._obm:
+                            data = self._download_obm_data_from_cos(cos_client=cos_client)
+
+                        else:
+                            data = self._download_data_from_cos(cos_client=cos_client)
                     else:
                         data = self._download_training_data_from_data_asset_storage()
 
@@ -563,7 +564,13 @@ class DataConnection(BaseDataConnection):
             except FileNotFoundError as e:
                 raise e
 
-            except Exception:
+            except Exception as e:
+                # do not try Flight is we are on the cloud
+                if (self._wml_client is not None and not self._wml_client.ICP) or (
+                    os.environ.get('USER_ACCESS_TOKEN') is None
+                ):
+                    raise e
+
                 data_location = self.location.to_dict()
                 data_location.update({'type': self.type})
 
@@ -605,7 +612,13 @@ class DataConnection(BaseDataConnection):
                     try:
                         data = self._download_data_from_nfs_connection()
 
-                    except Exception:
+                    except Exception as e:
+                        # do not try Flight is we are on the cloud
+                        if (self._wml_client is not None and not self._wml_client.ICP) or (
+                            os.environ.get('USER_ACCESS_TOKEN') is None
+                        ):
+                            raise e
+
                         try_import_pyarrow()
 
                         flight_service = FlightService(
@@ -1029,11 +1042,7 @@ class AssetLocation(BaseLocation):
     def _get_connection_id(self, client) -> str:
         attachment_content = self._get_attachment_details(client)
 
-        if 'connection_id' in attachment_content:
-            return attachment_content['connection_id']
-
-        else:
-            raise InvalidDataAsset()
+        return attachment_content.get('connection_id')
 
     @classmethod
     def _is_wsd(cls):
