@@ -132,7 +132,10 @@ class TensorflowPipelineModelContentLoader(object):
         try:
             from tensorflow import logging
             logging.set_verbosity(logging.WARN)
-            metagraphdef = tf.saved_model.loader.load(session, tags, content_dir)
+            if '2.1.0' in tf.__version__:
+                metagraphdef = tf.compat.v1.saved_model.loader.load(session, tags, content_dir)
+            else:
+                metagraphdef = tf.saved_model.loader.load(session, tags, content_dir)
 
             sig_def = list(metagraphdef.signature_def.values())[0]
             input_tensors = {}
