@@ -11,21 +11,25 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+import os
+import shutil
+import zipfile
 
-from  ibm_watson_machine_learning.libs.repo.util.unique_id_gen import uid_generate
-import os, shutil
+from ibm_watson_machine_learning.utils.autoai.utils import try_import_joblib
+from ibm_watson_machine_learning.libs.repo.util.unique_id_gen import uid_generate
 
 
 class HybridArtifactLoader(object):
     def load(self, artifact_queryparam):
+
         if artifact_queryparam is None:
-           return self.extract_content(artifact_queryparam, lambda content_dir: self.load_content(content_dir))
+           return self.extract_content(artifact_queryparam, HybridArtifactLoader._load_content)
 
         if artifact_queryparam is not None and artifact_queryparam == "full":
-            return self.extract_content(artifact_queryparam, lambda content_dir: self.load_content(content_dir))
+            return self.extract_content(artifact_queryparam, HybridArtifactLoader._load_content)
 
         if artifact_queryparam is not None and artifact_queryparam == "pipeline_model":
-            return self.extract_content_json(lambda content_dir: self.load_content(content_dir))
+            return self.extract_content_json()
 
     def extract_content(self, queryparam_val, callback):
         directory_name = 'artifact'
@@ -39,7 +43,6 @@ class HybridArtifactLoader(object):
             dir_id = uid_generate(id_length)
             model_dir_name = directory_name + dir_id
 
-            tar_file_name = '{}/artifact_content.tar'.format(model_dir_name)
             gz_file_name = '{}/artifact_content.tar.gz'.format(model_dir_name)
 
             input_stream = None
@@ -53,13 +56,19 @@ class HybridArtifactLoader(object):
             gz_f.write(file_content)
             gz_f.close()
             if queryparam_val is None:
-               self.reader().close()
-            return gz_file_name
+                self.reader().close()
+
+            with zipfile.ZipFile(gz_file_name) as zip_ref:
+                zip_ref.extractall(model_dir_name)
+            artifact_instance = callback(model_dir_name)
+
+            shutil.rmtree(model_dir_name)
+            return artifact_instance
         except Exception as ex:
             shutil.rmtree(model_dir_name)
             raise ex
 
-    def extract_content_json(self, callback):
+    def extract_content_json(self):
         directory_name = 'artifact'
         try:
             shutil.rmtree(directory_name)
@@ -85,13 +94,23 @@ class HybridArtifactLoader(object):
             raise ex
 
     def _content_reader_gzip(self):
-        if self._content_href is not None:
-            if self._content_href.__contains__("models"):
-                content_url = self._content_href + "?artifact=full"
-                return self.client.repository_api.download_artifact_content(content_url, 'false', accept='application/gzip')
+        if self._download_href is not None:
+            if self._download_href.__contains__("models"):
+                download_url = self._download_href + f"&space_id={self.meta.prop('space_id')}"\
+                                                     "&content_format=pipeline-node&pipeline_node_id=automl"
+                return self.client.repository_api.download_artifact_content_v4_cloud(download_url, 'true')
 
     def _content_reader_json(self):
-        if self._content_href is not None:
-            if self._content_href.__contains__("models"):
-                content_url = self._content_href + "?artifact=pipeline_model"
-                return self.client.repository_api.download_artifact_content(content_url, 'false', accept='application/json')
+        if self._download_href is not None:
+            if self._download_href.__contains__("models"):
+                download_url = self._download_href + f"&space_id={self.meta.prop('space_id')}&content_format=native"
+                return self.client.repository_api.download_artifact_content_v4_cloud(download_url, 'true')
+
+    @staticmethod
+    def _load_content(content_dir):
+        """
+        Load AutoAI pipeline into a local runtime.
+        """
+        joblib = try_import_joblib()
+        extracted_file = [file for file in os.listdir(content_dir) if file.endswith(".pickle")][0]
+        return joblib.load(os.path.join(content_dir, extracted_file))
