@@ -124,7 +124,7 @@ class RuntimesCollection:
         runtimes_patch_output = self.repository_api.v3_runtime_spec_patch_with_http_info(runtimes_patch_input, runtimes_id)
         statuscode = runtimes_patch_output[1]
 
-        if statuscode is not 200:
+        if statuscode != 200:
             logger.info('Error while patching runtimes: no location header')
             raise ApiException(statuscode, "Error while patching runtimes")
 
@@ -161,7 +161,7 @@ class RuntimesCollection:
                 raise IOError('The artifact specified ( {} ) does not exist.'.format(artifact.runtimespec_path))
 
         statuscode = runtimes_output[1]
-        if statuscode is not 201:
+        if statuscode != 201:
             logger.info('Error while creating runtimes: no location header')
             raise ApiException(statuscode, 'No artifact location')
 
