@@ -872,10 +872,9 @@ class ModelDefinition(WMLResource):
                     if key == 'name' or key == 'description':
                         props_for_asset_meta_patch.update({key: meta_props[key]})
 
-                meta_patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['metadata'],
-                                                                                         props_for_asset_meta_patch,
-                                                                                         with_validation=True,
-                                                                                         asset_meta_patch=True)
+            meta_patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details,
+                                                                                     props_for_asset_meta_patch,
+                                                                                     with_validation=True)
 
             props_for_asset_entity_patch = {}
             for key in meta_props:
@@ -884,8 +883,7 @@ class ModelDefinition(WMLResource):
 
             entity_patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity']['wml_model_definition'],
                                                                                        props_for_asset_entity_patch,
-                                                                                       with_validation=True,
-                                                                                       asset_meta_patch=False)
+                                                                                       with_validation=True)
 
             if meta_patch_payload:
                 meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
