@@ -160,10 +160,10 @@ class Script(WMLResource):
 
         ##Step1: Create a data asset
         f = {'file': open(file_path, 'rb')}
-        name = script_meta[u'name']
+        name = script_meta['metadata'][u'name']
 
-        if script_meta.get('description') is not None:
-            desc = script_meta[u'description']
+        if script_meta['metadata'].get('description') is not None:
+            desc = script_meta['metadata'][u'description']
         else:
             desc = ""
 
