@@ -121,7 +121,7 @@ class Shiny(WMLResource):
             client=self._client
         )
 
-        response = self._create_asset(shiny_meta, file_path)
+        response = self._create_asset(shiny_meta['metadata'], file_path)
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             return response
