@@ -18,13 +18,12 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                     create_bucket, get_space_id)
+                                                     create_bucket, get_space_id, create_connection_to_cos)
 from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
@@ -102,36 +101,29 @@ class TestAutoAIRemote(unittest.TestCase):
 
         cls.project_id = cls.wml_credentials.get('project_id')
 
-
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
                                    cos_resource_instance_id=self.cos_resource_instance_id),
                       days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
-                                     cos_resource_instance_id=self.cos_resource_instance_id)
+                                                 cos_resource_instance_id=self.cos_resource_instance_id)
         if self.wml_client.ICP:
             self.wml_client.set.default_project(self.project_id)
         else:
             self.wml_client.set.default_space(self.space_id)
 
-
     def test_00b_prepare_COS_instance(self):
-        if self.wml_client.ICP:
-            self.skipTest("Prepare COS is available only for Cloud")
-        import ibm_boto3
-        cos_resource = ibm_boto3.resource(
-            service_name="s3",
-            endpoint_url=self.cos_endpoint,
-            aws_access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-            aws_secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']
-        )
-        # Prepare bucket
-        if not bucket_exists(cos_resource, self.bucket_name):
-            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
+        TestAutoAIRemote.connection_id, TestAutoAIRemote.bucket_name = create_connection_to_cos(
+            wml_client=self.wml_client,
+            cos_credentials=self.cos_credentials,
+            cos_endpoint=self.cos_endpoint,
+            bucket_name=self.bucket_name,
+            save_data=True,
+            data_path=self.data_location,
+            data_cos_path=self.data_cos_path)
 
-            self.assertIsNotNone(TestAutoAIRemote.bucket_name)
-            self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
+        self.assertIsInstance(self.connection_id, str)
 
         print(f"Using COS bucket: {TestAutoAIRemote.bucket_name}")
 
@@ -145,10 +137,10 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
             TestAutoAIRemote.data_connection = DataConnection(
-                            location=FSLocation(path=self.data_location))
+                location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
 
-        else: #for cloud and COS
+        else:  # for cloud and COS
             TestAutoAIRemote.data_connection = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
@@ -180,8 +172,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column=self.prediction_column,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN,Transformers.SUM],
+            cognito_transform_names=[Transformers.DIFF, Transformers.SUM, Transformers.MAX,
+                                     Transformers.SIN, Transformers.SUM],
             holdout_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
@@ -209,7 +201,8 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
 
-        step = self.trained_pipeline_details['entity']['status']['metrics'][0]['context']['intermediate_model']['composition_steps'][0]
+        step = self.trained_pipeline_details['entity']['status']['metrics'][0]['context']['intermediate_model'][
+            'composition_steps'][0]
         TestAutoAIRemote.row_no_with_drop = int(step.split('_')[2])
         print(TestAutoAIRemote.row_no_with_drop)
         self.assertEqual(TestAutoAIRemote.row_no_with_drop, 147)
@@ -221,8 +214,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column=self.prediction_column,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN,Transformers.SUM],
+            cognito_transform_names=[Transformers.DIFF, Transformers.SUM, Transformers.MAX,
+                                     Transformers.SIN, Transformers.SUM],
             holdout_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
@@ -235,8 +228,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_07_get_configuration_parameters_of_remote_auto_pipeline(self):
         parameters = self.remote_auto_pipelines.get_params()
         print(parameters)
-        assert('drop_duplicates' in parameters)
-        assert(not parameters['drop_duplicates'])
+        assert ('drop_duplicates' in parameters)
+        assert (not parameters['drop_duplicates'])
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
     def test_08_fit_run_training_of_auto_ai_in_wml(self):
@@ -250,7 +243,8 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
 
-        step = self.trained_pipeline_details['entity']['status']['metrics'][0]['context']['intermediate_model']['composition_steps'][0]
+        step = self.trained_pipeline_details['entity']['status']['metrics'][0]['context']['intermediate_model'][
+            'composition_steps'][0]
         TestAutoAIRemote.row_no_without_drop = int(step.split('_')[2])
         print(TestAutoAIRemote.row_no_without_drop)
         self.assertEqual(TestAutoAIRemote.row_no_without_drop, 150)
@@ -259,5 +253,6 @@ class TestAutoAIRemote(unittest.TestCase):
         print(TestAutoAIRemote.row_no_with_drop, TestAutoAIRemote.row_no_without_drop)
         self.assertNotEqual(TestAutoAIRemote.row_no_with_drop, TestAutoAIRemote.row_no_without_drop)
 
+
 if __name__ == '__main__':
     unittest.main()
