@@ -5,7 +5,7 @@ import ibm_boto3
 from ibm_watson_machine_learning.helpers.connections import DataConnection, S3Location
 from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit, WMLClientError
 from ibm_watson_machine_learning.tests.utils import bucket_exists, create_bucket, is_cp4d
-from ibm_watson_machine_learning.tests.autoai.svt.abstract_test_iris_wml_autoai_multiclass_connections import (
+from ibm_watson_machine_learning.tests.autoai.abstract_tests_classes import (
     AbstractTestAutoAIRemote)
 
 
