@@ -6,10 +6,6 @@ from base_class_V4test_online_deployment import TestBaseOnlineDeployment
 class TestAIFunction(TestBase, TestBaseOnlineDeployment, unittest.TestCase):
     deployment_name = "ai_function_deployment"
     model_name = "ai_function_model"
-    scoring_payload = [{
-        "fields": ["multiplication"],
-        "values": [[2.0, 2.0], [99.0, 99.0]]
-    }]
     sw_spec_name = 'default_py3.8'
 
     def create_model(self, sw_spec_id) -> str:
@@ -29,12 +25,11 @@ class TestAIFunction(TestBase, TestBaseOnlineDeployment, unittest.TestCase):
 
         return self.wml_client.repository.get_function_uid(ai_function_details)
 
-    def patch_model(self):
-        function_props = {
-            self.wml_client.repository.FunctionMetaNames.DESCRIPTION: 'desc',
-        }
-
-        details = self.wml_client.repository.update_function(TestAIFunction.model_uid, function_props)
+    def get_scoring_payload(self):
+        return [{
+            "fields": ["multiplication"],
+            "values": [[2.0, 2.0], [99.0, 99.0]]
+        }]
 
 
 if __name__ == '__main__':
