@@ -5,6 +5,7 @@ import datetime
 from configparser import ConfigParser
 from functools import wraps
 from time import sleep
+import ibm_boto3
 
 from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup
 
@@ -21,16 +22,17 @@ __all__ = [
     "get_space_id",
     "resources_discovery",
     "find_not_freed_resources",
-    "setup_nfs_env"
+    "setup_nfs_env",
+    "save_data_to_container",
+    "save_data_to_cos_bucket",
+    "create_connection_to_cos"
 ]
 
-
 if "ENV" in os.environ:
     environment = os.environ['ENV']
 else:
     environment = "YP_QA"
 
-
 timeouts = "TIMEOUTS"
 credentials = "CREDENTIALS"
 training_data = "TRAINING_DATA"
@@ -111,6 +113,7 @@ def create_bucket(cos_resource, bucket_name):
 
 def print_test_separators(method):
     """Printing visual separators for tests."""
+
     @wraps(method)
     def _method(*method_args, **method_kwargs):
         print("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!")
@@ -150,7 +153,7 @@ def get_space_id(wml_client, space_name, cos_resource_instance_id=None):
         details = wml_client.spaces.store(meta_props=metadata, background_mode=False)
         space_id = details['metadata'].get('id')
         print(f"New space `{space_name}` has been created, space_id={space_id}")
-        sleep(5) # wait for space preparing
+        sleep(5)  # wait for space preparing
 
     return space_id
 
@@ -256,7 +259,8 @@ def setup_nfs_env(wml_credentials, dataset_file_name, remote_directory='datasets
         res = run_ssh(f'oc project {namespace} --kubeconfig /root/auth/kubeconfig')
         print(res)
     except:
-        raise Exception("Cannot change project to correct one for this cluster. Probably cluster changed. Add to credentials kube_username and make sure ssh credentials match the cluster.")
+        raise Exception(
+            "Cannot change project to correct one for this cluster. Probably cluster changed. Add to credentials kube_username and make sure ssh credentials match the cluster.")
 
     # Check if there is already an existing NFS storage class
     res = run_ssh('oc get storageclass --kubeconfig /root/auth/kubeconfig')
@@ -377,7 +381,8 @@ def setup_nfs_env(wml_credentials, dataset_file_name, remote_directory='datasets
             break
 
     if res['services_status'] == 'FAILED':
-        raise Exception(f'Volume `{volume_name}` failed to run. Probably wrong cluster is set in login and as project. The project when `oc project` should be `{namespace}`')
+        raise Exception(
+            f'Volume `{volume_name}` failed to run. Probably wrong cluster is set in login and as project. The project when `oc project` should be `{namespace}`')
 
     if res['services_status'] != 'RUNNING':
         raise Exception(f'Volume `{volume_name}` not running.')
@@ -451,3 +456,91 @@ def setup_nfs_env(wml_credentials, dataset_file_name, remote_directory='datasets
 
     return connection_id, f"/{remote_directory}/{dataset_file_name}", asset_id
 
+
+def save_data_to_container(data_path, data_cos_path, wml_client):
+    import requests
+
+    if wml_client.default_space_id:
+        details = wml_client.spaces.get_details(wml_client.default_space_id)
+
+    elif wml_client.default_project_id:
+        project_url = wml_client.service_instance._href_definitions.get_project_href(
+            wml_client.default_project_id)
+        if wml_client.ICP:
+            response = requests.get(
+                project_url,
+                headers=wml_client._get_headers(),
+                verify=False
+            )
+
+        else:
+            response = requests.get(
+                project_url,
+                headers=wml_client._get_headers()
+            )
+
+        details = response.json()
+    else:
+        raise ValueError("WML client should have set default project or space id.")
+
+    properties = details['entity']['storage']['properties']
+    properties.update(details['entity']['storage']['properties']['credentials']['editor'])
+    properties.update(details['entity']['storage']['properties']['credentials']['editor'])
+
+    save_data_to_cos_bucket(data_path=data_path,
+                            data_cos_path=data_cos_path,
+                            access_key_id=properties.get('access_key_id'),
+                            secret_access_key=properties.get('secret_access_key'),
+                            cos_endpoint=properties['endpoint_url'],
+                            bucket_name=properties['bucket_name'],
+                            is_container=True)
+
+
+def save_data_to_cos_bucket(data_path, data_cos_path, access_key_id, secret_access_key, cos_endpoint, bucket_name,
+                            is_container=False):
+    cos_resource = ibm_boto3.resource(
+        service_name="s3",
+        endpoint_url=cos_endpoint,
+        aws_access_key_id=access_key_id,
+        aws_secret_access_key=secret_access_key
+    )
+
+    # Prepare bucket
+    if not is_container:
+        if not bucket_exists(cos_resource, bucket_name):
+            bucket_name = create_bucket(cos_resource, bucket_name)
+
+            assert bucket_exists(cos_resource, bucket_name)
+
+    # Write data to cos bucket
+    cos_resource.Bucket(bucket_name).upload_file(data_path, data_cos_path)
+
+    return bucket_name
+
+
+def create_connection_to_cos(wml_client, cos_credentials, cos_endpoint, bucket_name, save_data=False, data_path=None,
+                             data_cos_path=None):
+    if save_data and data_path and data_cos_path:
+        bucket_name = save_data_to_cos_bucket(data_path, data_cos_path, cos_credentials['cos_hmac_keys']['access_key_id'],
+                                cos_credentials['cos_hmac_keys']['secret_access_key'], cos_endpoint, bucket_name,
+                                is_container=False)
+
+    auth_endpoint = cos_credentials.get('auth_endpoint')
+    if auth_endpoint is None:
+        auth_endpoint = wml_client.service_instance._href_definitions.get_iam_token_url()
+
+    connection_details = wml_client.connections.create({
+        'datasource_type': wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage'),
+        'name': 'Connection to COS for tests',
+        'properties': {
+            'bucket': bucket_name,
+            'access_key': cos_credentials['cos_hmac_keys']['access_key_id'],
+            'secret_key': cos_credentials['cos_hmac_keys']['secret_access_key'],
+            'iam_url': auth_endpoint,
+            'url': cos_endpoint
+        }
+    })
+
+    connection_id = wml_client.connections.get_uid(connection_details)
+
+    return connection_id, bucket_name
