@@ -522,7 +522,7 @@ class Training(WMLResource):
         resources = details[u'resources']
         values = [(m[u'metadata'].get('id', m[u'metadata'].get('guid')), m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
 
-        self._list(values, [u'ID (training)', u'STATE', u'CREATED'], limit, 50)
+        self._list(values, [u'ID (training)', u'STATE', u'CREATED'], limit, 100, sort_by=None)
 
     def list_subtrainings(self, training_uid):
         """
